#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui>


class PictureItem: public QObject, public QGraphicsPixmapItem
{
Q_OBJECT
    // For Property animation:

    // Change picture position
    Q_PROPERTY(QPointF pos READ pos WRITE setPos)

    // Rotating picture
    Q_PROPERTY(qreal rotationAngleY READ rotationAngleY WRITE setRotationAngleY)

    // Fade picture
    Q_PROPERTY(int fade READ fade WRITE setFade)

    // Scale picture
    Q_PROPERTY(qreal scale READ scale WRITE setScale)

public:
    enum
    {
        PictureItemType = UserType + 1
    };

public:
    PictureItem(QSizeF size, const QPixmap& pixmap = 0, QObject* parent = 0);
    ~PictureItem();

    QRectF boundingRect() const;

    int type() const
    {
        return PictureItemType;
    }

    // For rotationAngleY property
    void setRotationAngleY(qreal angle);
    qreal rotationAngleY() const;

    // For fade property
    void setFade(int f);
    int fade() const;

    // Animate position of this class
    void animatePosition(const QPointF& start, const QPointF& end);

    // Animate angle of this class
    void animateAngle(int startAngle, int endAngle);

    // Animate position and angle
    void animatePosAndAngle(const QPointF& start, const QPointF& end,
                            int startAngle, int endAngle);

    // Animate fade effects for this class
    void animateFadeIn();
    void animateFadeOut();

    // Animate scale for this class
    void animateScale(qreal start, qreal end);

public slots:
    void animationFinished();

private:
    QSizeF m_size;
    qreal m_rotationAngleY;
    int m_fade;
    QPixmap m_originalPicForFade;
};



class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();



    void resizeEvent(QResizeEvent *);
    void mousePressEvent(QMouseEvent *);
    void createMenu();
    void coloraGrafico();
    void vuotaGrafico();

public slots:
    void animatePos();
    void animateAngle();
    void animateFadeIn();
    void animateFadeOut();
    void animateScale();
    void animatePosAndAngle();
    void imposta();
    void prepara();
    void setParametri();
    void setAnnulla();
    void controlloUnita(const QString & text);
    void controlloDecine(const QString & text);
    void controlloCentinaia(const QString & text);
    void controlloRiportoDecine(const QString & text);
    void controlloRiportoCentinaia(const QString & text);
    void fine(void);

private:
    QButtonGroup *bgU,*bgD,*bgC;
    QCheckBox *cbRipDec,*cbRipCen;
    QFont *fnNumbers,*fnHelp,*fnLittle;
    QGraphicsScene* m_scene;
    QGraphicsView* m_view;
    QGroupBox *gbImposta,*gbNome,*gbMinAdd,*gbMaxAdd,*gbMaxTot,*gbMinTot,*gbRip,*gbSeme,*gbAnim;
		QLabel *laU1,*laU2,*laD1, *laD2, *laC1, *laC2, *laPiu, *laUguale,*laGuida,*laCol[10],
           *laCU,*laCD,*laCC,*laColori;
		QLineEdit  *leRD, *leRC, *leTC, *leTD, *leTU,*leNome,*leMinAdd,*leMaxAdd,*leMinTot,*leMaxTot,
           *leSeme,*leAnim;
    QPointF m_center;
    QPushButton* pbSomma,*pbImposta,*pbOk,*pbAnnulla,*pbHelp,*pbBasta;
		QRadioButton *rbU[10],*rbD[10],*rbC[10];
    PictureItem* m_item[160],* m_itemb;


};

#endif // MAINWINDOW_H
